Struct

SpiceClientGLibSmartcardReader

Description [src]

struct SpiceSmartcardReader {
  /* No available fields */
}

The SpiceSmartcardReader struct is opaque and cannot be accessed directly.

Instance methods

spice_smartcard_reader_insert_card

Simulates insertion of a smartcard in the software smartcard reader reader. If reader is not a software smartcard reader, FALSE will be returned.

spice_smartcard_reader_is_software

Tests if reader is a software (emulated) smartcard reader.

spice_smartcard_reader_remove_card

Simulates removal of a smartcard from the software smartcard reader reader. If reader is not a software smartcard reader, FALSE will be returned.